==> ejc-zjkjcost-impl-3.0.0-20221103.080619-75-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/AllocateDetailEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部人员风险金预留子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_allocate_detail")
public class AllocateDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allocate_id")
    private Long allocateId; // 主表主键ID
    @TableField(value="personnel_id")
    private Long personnelId; // 人员ID
    @TableField(value="personnel_name")
    private String personnelName; // 人员名称
    @TableField(value="personnel_code")
    private String personnelCode; // 人员编号
    @TableField(value="post_name")
    private String postName; // 岗位职务
    @TableField(value="should_detail_mny")
    private BigDecimal shouldDetailMny; // 应预留风险金额
    @TableField(value="actual_detail_mny")
    private BigDecimal actualDetailMny; // 实际预留风险金额
    @TableField(value="detail_ratio")
    private BigDecimal detailRatio; // 预留风险比例
    @TableField(value="before_should_detail_mny")
    private BigDecimal beforeShouldDetailMny; // 变更前应预留风险金额
    @TableField(value="before_actual_detail_mny")
    private BigDecimal beforeActualDetailMny; // 变更前实际预留风险金额
    @TableField(value="before_detail_ratio")
    private BigDecimal beforeDetailRatio; // 变更前预留风险比例
    @TableField(value="change_type")
    private Integer changeType; // 变更类型:0-未变更 1-增补项，2-删除项，3-变更项
    @TableField(value="target_detail_id")
    private Long targetDetailId; // 变更项原数据Id
    @TableField(value="before_file_ids")
    private String beforeFileIds; // 变更前附件id集合串
    @TableField(value="file_ids")
    private String fileIds; // 附件id集合串
    @TableField(value="fhzdlt_ids")
    private String fhzdltIds; // 返还、转抵、离退id集合串
    @TableField(value="return_mortgage_mny")
    private BigDecimal returnMortgageMny;
    @TableField(value="Actual_balance_mny")
    private BigDecimal ActualBalanceMny;
    @TableField(value="should_balance_mny")
    private BigDecimal shouldBalanceMny;
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAllocateId() {
        return allocateId;
    }

    public void setAllocateId(Long allocateId) {
        this.allocateId = allocateId;
    }
    public Long getPersonnelId() {
        return personnelId;
    }

    public void setPersonnelId(Long personnelId) {
        this.personnelId = personnelId;
    }
    public String getPersonnelName() {
        return personnelName;
    }

    public void setPersonnelName(String personnelName) {
        this.personnelName = personnelName;
    }
    public String getPersonnelCode() {
        return personnelCode;
    }

    public void setPersonnelCode(String personnelCode) {
        this.personnelCode = personnelCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public BigDecimal getShouldDetailMny() {
        return shouldDetailMny;
    }

    public void setShouldDetailMny(BigDecimal shouldDetailMny) {
        this.shouldDetailMny = shouldDetailMny;
    }
    public BigDecimal getActualDetailMny() {
        return actualDetailMny;
    }

    public void setActualDetailMny(BigDecimal actualDetailMny) {
        this.actualDetailMny = actualDetailMny;
    }
    public BigDecimal getDetailRatio() {
        return detailRatio;
    }

    public void setDetailRatio(BigDecimal detailRatio) {
        this.detailRatio = detailRatio;
    }
    public BigDecimal getBeforeShouldDetailMny() {
        return beforeShouldDetailMny;
    }

    public void setBeforeShouldDetailMny(BigDecimal beforeShouldDetailMny) {
        this.beforeShouldDetailMny = beforeShouldDetailMny;
    }
    public BigDecimal getBeforeActualDetailMny() {
        return beforeActualDetailMny;
    }

    public void setBeforeActualDetailMny(BigDecimal beforeActualDetailMny) {
        this.beforeActualDetailMny = beforeActualDetailMny;
    }
    public BigDecimal getBeforeDetailRatio() {
        return beforeDetailRatio;
    }

    public void setBeforeDetailRatio(BigDecimal beforeDetailRatio) {
        this.beforeDetailRatio = beforeDetailRatio;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetDetailId() {
        return targetDetailId;
    }

    public void setTargetDetailId(Long targetDetailId) {
        this.targetDetailId = targetDetailId;
    }
    public String getBeforeFileIds() {
        return beforeFileIds;
    }

    public void setBeforeFileIds(String beforeFileIds) {
        this.beforeFileIds = beforeFileIds;
    }
    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }
    public String getFhzdltIds() {
        return fhzdltIds;
    }

    public void setFhzdltIds(String fhzdltIds) {
        this.fhzdltIds = fhzdltIds;
    }

    public BigDecimal getReturnMortgageMny() {
        return returnMortgageMny;
    }

    public void setReturnMortgageMny(BigDecimal returnMortgageMny) {
        this.returnMortgageMny = returnMortgageMny;
    }

    public BigDecimal getActualBalanceMny() {
        return ActualBalanceMny;
    }

    public void setActualBalanceMny(BigDecimal actualBalanceMny) {
        ActualBalanceMny = actualBalanceMny;
    }

    public BigDecimal getShouldBalanceMny() {
        return shouldBalanceMny;
    }

    public void setShouldBalanceMny(BigDecimal shouldBalanceMny) {
        this.shouldBalanceMny = shouldBalanceMny;
    }
}

==> ejc-zjkjcost-impl-3.0.0-20221115.101851-98-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/AllocateDetailEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部人员风险金预留子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_allocate_detail")
public class AllocateDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allocate_id")
    private Long allocateId; // 主表主键ID
    @TableField(value="personnel_id")
    private Long personnelId; // 人员ID
    @TableField(value="personnel_name")
    private String personnelName; // 人员名称
    @TableField(value="personnel_code")
    private String personnelCode; // 人员编号
    @TableField(value="post_name")
    private String postName; // 岗位职务
    @TableField(value="should_detail_mny")
    private BigDecimal shouldDetailMny; // 应预留风险金额
    @TableField(value="actual_detail_mny")
    private BigDecimal actualDetailMny; // 实际预留风险金额
    @TableField(value="detail_ratio")
    private BigDecimal detailRatio; // 预留风险比例
    @TableField(value="before_should_detail_mny")
    private BigDecimal beforeShouldDetailMny; // 变更前应预留风险金额
    @TableField(value="before_actual_detail_mny")
    private BigDecimal beforeActualDetailMny; // 变更前实际预留风险金额
    @TableField(value="before_detail_ratio")
    private BigDecimal beforeDetailRatio; // 变更前预留风险比例
    @TableField(value="change_type")
    private Integer changeType; // 变更类型:0-未变更 1-增补项，2-删除项，3-变更项
    @TableField(value="target_detail_id")
    private Long targetDetailId; // 变更项原数据Id
    @TableField(value="before_file_ids")
    private String beforeFileIds; // 变更前附件id集合串
    @TableField(value="file_ids")
    private String fileIds; // 附件id集合串
    @TableField(value="fhzdlt_ids")
    private String fhzdltIds; // 返还、转抵、离退id集合串
    @TableField(value="return_mortgage_mny")
    private BigDecimal returnMortgageMny;//返还金额
    @TableField(value="Actual_balance_mny")
    private BigDecimal ActualBalanceMny;
    @TableField(value="should_balance_mny")
    private BigDecimal shouldBalanceMny;

    @TableField(value="mortgage_mny")
    private BigDecimal MortgageMny;//转抵金额
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAllocateId() {
        return allocateId;
    }

    public void setAllocateId(Long allocateId) {
        this.allocateId = allocateId;
    }
    public Long getPersonnelId() {
        return personnelId;
    }

    public void setPersonnelId(Long personnelId) {
        this.personnelId = personnelId;
    }
    public String getPersonnelName() {
        return personnelName;
    }

    public void setPersonnelName(String personnelName) {
        this.personnelName = personnelName;
    }
    public String getPersonnelCode() {
        return personnelCode;
    }

    public void setPersonnelCode(String personnelCode) {
        this.personnelCode = personnelCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public BigDecimal getShouldDetailMny() {
        return shouldDetailMny;
    }

    public void setShouldDetailMny(BigDecimal shouldDetailMny) {
        this.shouldDetailMny = shouldDetailMny;
    }
    public BigDecimal getActualDetailMny() {
        return actualDetailMny;
    }

    public void setActualDetailMny(BigDecimal actualDetailMny) {
        this.actualDetailMny = actualDetailMny;
    }
    public BigDecimal getDetailRatio() {
        return detailRatio;
    }

    public void setDetailRatio(BigDecimal detailRatio) {
        this.detailRatio = detailRatio;
    }
    public BigDecimal getBeforeShouldDetailMny() {
        return beforeShouldDetailMny;
    }

    public void setBeforeShouldDetailMny(BigDecimal beforeShouldDetailMny) {
        this.beforeShouldDetailMny = beforeShouldDetailMny;
    }
    public BigDecimal getBeforeActualDetailMny() {
        return beforeActualDetailMny;
    }

    public void setBeforeActualDetailMny(BigDecimal beforeActualDetailMny) {
        this.beforeActualDetailMny = beforeActualDetailMny;
    }
    public BigDecimal getBeforeDetailRatio() {
        return beforeDetailRatio;
    }

    public void setBeforeDetailRatio(BigDecimal beforeDetailRatio) {
        this.beforeDetailRatio = beforeDetailRatio;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetDetailId() {
        return targetDetailId;
    }

    public void setTargetDetailId(Long targetDetailId) {
        this.targetDetailId = targetDetailId;
    }
    public String getBeforeFileIds() {
        return beforeFileIds;
    }

    public void setBeforeFileIds(String beforeFileIds) {
        this.beforeFileIds = beforeFileIds;
    }
    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }
    public String getFhzdltIds() {
        return fhzdltIds;
    }

    public void setFhzdltIds(String fhzdltIds) {
        this.fhzdltIds = fhzdltIds;
    }

    public BigDecimal getReturnMortgageMny() {
        return returnMortgageMny;
    }

    public void setReturnMortgageMny(BigDecimal returnMortgageMny) {
        this.returnMortgageMny = returnMortgageMny;
    }

    public BigDecimal getActualBalanceMny() {
        return ActualBalanceMny;
    }

    public void setActualBalanceMny(BigDecimal actualBalanceMny) {
        ActualBalanceMny = actualBalanceMny;
    }

    public BigDecimal getShouldBalanceMny() {
        return shouldBalanceMny;
    }

    public void setShouldBalanceMny(BigDecimal shouldBalanceMny) {
        this.shouldBalanceMny = shouldBalanceMny;
    }

    public BigDecimal getMortgageMny() {
        return MortgageMny;
    }

    public void setMortgageMny(BigDecimal mortgageMny) {
        MortgageMny = mortgageMny;
    }
}
